<?php if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Theme Actions
 *
 * This is where theme functions are hooked into the appropriate hooks / filters.
 *
 * @since 	1.0.0
 * @author 	WooThemes
 */

// Enqueue Styles
add_action( 'wp_enqueue_scripts', 'woo_child_enqueue', 30 );
add_action( 'wp_enqueue_scripts', 'woo_google_fonts' );

// Move things around
add_action( 'init', 'woo_layout_adjust', 10 );

// Homepage
add_action( 'homepage', 'woo_display_recent_posts', 10 );
add_action( 'homepage', 'woo_display_contact', 20 );
add_action( 'homepage', 'woo_display_testimonials', 30 );
add_action( 'woo_header_before', 'woo_hero_wrapper', 10 );
add_action( 'woo_header_after', 'woo_header_contact', 7 );
add_action( 'woo_header_after', 'woo_display_hero', 20 );
add_action( 'woo_header_after', 'woo_hero_wrapper_close', 30 );

// Output Custom Fonts
add_action( 'wp_head', 'woo_custom_fonts_output', 10 );

// Setting overrides
add_filter( 'option_woo_options', 'woo_custom_theme_overrides' );

// Plugin integrations
add_action( 'after_setup_theme', 'bon_appetit_plugin_support' );
add_filter( 'wf_get_plugins_to_look_for', 'bon_appetit_plugin_integrations' );

/**
 * Child Theme Enqueues
 *
 * Enqueues Custom Fonts and Stylesheet files.
 *
 * @since  	1.0.0
 * @return 	void
 * @author 	WooThemes
 */
function woo_child_enqueue() {
	// Load Theme Stylesheet
	wp_enqueue_style( 'bon-appetit', get_stylesheet_directory_uri() . '/css/bon-appetit.css' );

	// Load JS
	wp_enqueue_script( 'bon-appetit-general', get_stylesheet_directory_uri() . '/js/general.min.js', array( 'jquery' ) );
}

/**
 * Move things around
 *
 * Moves elements from their default location
 *
 * @since  	1.0.0
 * @return 	void
 * @author 	WooThemes
 */
function woo_layout_adjust() {
	if ( ! is_page_template( 'template-homepage.php' ) ) {
		remove_action( 'woo_main_after', 'woocommerce_get_sidebar', 10 );
	}

	remove_action( 'woo_top', 'woo_top_navigation', 10 );
	add_action( 'woo_header_before', 'woo_top_navigation', 15 );

	remove_action( 'woo_header_after','woo_nav', 10 );
	add_action( 'woo_header_inside','woo_nav', 10 );
}

/**
 * Add Lato Google Font
 * @return string stylesheet
 * @since  1.0.0
 */
function woo_google_fonts() {
	wp_enqueue_style( 'Lato', '//fonts.googleapis.com/css?family=Lato:300,400,700,400italic' );
	wp_enqueue_style( 'Vollkorn', '//fonts.googleapis.com/css?family=Vollkorn:400italic,400,700' );
}

/**
 * Theme Overrides
 *
 * Updates Theme Options dynamically to match the styling of the Child Theme.
 *
 * @since  	1.0.0
 * @return 	array
 * @author 	WooThemes
 */

function woo_custom_theme_overrides( $options ) {
	$headings 	= 'Lato';
	$body 		= 'Vollkorn';

	if ( ! isset( $options['woo_child_theme_overrides'] ) ) {
		$options['woo_child_theme_overrides'] = 'true';
	}

	if ( 'false' != $options['woo_child_theme_overrides'] ) {
		$options['woo_style_disable'] = 'false';

		// Misc
		$options['woo_font_text'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => $body, 'style' => 'normal', 'color' => '#80796f' );
		$options['woo_font_h1'] 	= array( 'size' => '2.6', 'unit' => 'em', 'face' => $headings, 'style' => '300', 'color' => '#e0dfdd' );
		$options['woo_font_h2'] 	= array( 'size' => '2.2', 'unit' => 'em', 'face' => $headings, 'style' => '300', 'color' => '#e0dfdd' );
		$options['woo_font_h3'] 	= array( 'size' => '1.6', 'unit' => 'em', 'face' => $headings, 'style' => '300', 'color' => '#e0dfdd' );
		$options['woo_font_h4'] 	= array( 'size' => '1.3', 'unit' => 'em', 'face' => $headings, 'style' => '300', 'color' => '#e0dfdd' );
		$options['woo_font_h5'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => $headings, 'style' => '400', 'color' => '#e0dfdd' );
		$options['woo_font_h6'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => $headings, 'style' => '400', 'color' => '#e0dfdd' );

		// Top Navigation
		$options['woo_top_nav_font'] = array( 'size' => '.9', 'unit' => 'em', 'face' => $body, 'style' => 'normal', 'color' => '#8c8981' );

		// Header
		$options['woo_font_logo'] 				= array( 'size' => '1.8', 'unit' => 'em', 'face' => $headings, 'style' => '400', 'color' => '#ffffff' );
		$options['woo_font_desc'] 				= array( 'size' => '1', 'unit' => 'em', 'face' => $body, 'style' => 'normal', 'color' => '#c7aa98' );
		$options['woo_header_bg'] 				= '';
		$options['woo_header_padding_bottom'] 	= '40';
		$options['woo_header_padding_top'] 		= '40';
		$options['woo_header_cart_link']		= 'false';
		$options['woo_header_cart_total']		= 'false';
		$options['woo_nav_rss']					= 'false';
		$options['woo_subscribe_email']			= false;
		$options['woo_nav_search']				= 'false';

		// Primary Navigation
		$options['woo_nav_font'] 		= array( 'size' => '1', 'unit' => 'em', 'face' => $headings, 'style' => 'normal', 'color' => '#ffffff' );
		$options['woo_nav_bg'] 			= '';
		$options['woo_nav_hover_bg'] 	= '';

		// Posts / Pages
		$options['woo_font_post_title'] 	= array( 'size' => '2', 'unit' => 'em', 'face' => $headings, 'style' => '400', 'color' => '#e0dfdd' );
		$options['woo_font_post_meta'] 		= array( 'size' => '.9', 'unit' => 'em', 'face' => $body, 'style' => 'normal', 'color' => '#8c8981' );
		$options['woo_font_post_text'] 		= array( 'size' => '1', 'unit' => 'em', 'face' => $body, 'style' => 'normal', 'color' => '#80796f' );
		$options['woo_font_post_more'] 		= array( 'size' => '1', 'unit' => 'em', 'face' => $body, 'style' => 'normal', 'color' => '#999' );
		$options['woo_pagenav_font'] 		= array( 'size' => '1', 'unit' => 'em', 'face' => $body, 'style' => 'normal', 'color' => '#80796f' );



		// Post Author
		$options['woo_post_author_border_top'] 		= array( 'width' => '0', 'style' => 'solid', 'color' => '' );
		$options['woo_post_author_border_bottom'] 	= array( 'width' => '0', 'style' => 'solid', 'color' => '' );
		$options['woo_post_author_border_lr'] 		= array( 'width' => '0', 'style' => 'solid', 'color' => '' );
		$options['woo_post_author_border_radius'] 	= '0px';
		$options['woo_post_author_bg'] 				= '#221a13';

		// Archives
		$options['woo_archive_header_font'] 			= array( 'size' => '1.8', 'unit' => 'em', 'face' => $headings, 'style' => '400', 'color' => '#e0dfdd' );
		$options['woo_archive_header_border_bottom'] 	= array( 'width' => '1', 'style' => 'solid', 'color' => '#373028' );

		// Widgets
		$options['woo_widget_font_title'] 	= array( 'size' => '1.4', 'unit' => 'em', 'face' => $headings, 'style' => '400', 'color' => '#e0dfdd' );
		$options['woo_widget_font_text'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => $body, 'style' => 'normal', 'color' => '#80796f' );
		$options['woo_widget_title_border'] = array( 'width' => '0', 'style' => 'solid', 'color' => '#00000' );
		$options['woo_widget_bg'] 			= '#1a150f';

		// Footer
		$options['woo_footer_font'] = array( 'size' => '1', 'unit' => 'em', 'face' => $body, 'style' => 'normal', 'color' => '#8c8981' );
		$options['woo_footer_bg'] 	= '';

		// Background
		$options['woo_style_bg_image_attach'] = 'fixed';
		$options['woo_style_bg_image_repeat'] = 'repeat';

		// Full Width
		$options['woo_foot_full_width_widget_bg'] 	= '#4C5567';
		$options['woo_footer_full_width_bg'] 		= '#4C5567';
		$options['woo_footer_border_top'] 			= array( 'width' => '0', 'style' => 'solid', 'color' => '#00000' );

	}

	return $options;
}

/**
 * Add Custom Options
 *
 * Add custom options for this Child Theme.
 *
 * @since  	1.0.0
 * @return 	array
 * @author 	WooThemes
 */
function woo_options_add( $options ) {

	$shortname = 'woo';

	$options[] = array( 'name' 		=> __( 'Bon Appétit', 'woothemes' ),
						'icon' 		=> 'misc',
					    'type' 		=> 'heading' );

	$options[] = array( "name" 		=> __( 'Use Child Theme Custom Overrides', 'woothemes' ),
						"desc" 		=> __( 'Disable this option if you\'d like to setup your own typography and layout settings.', 'woothemes' ),
						"id" 		=> $shortname."_child_theme_overrides",
						"std" 		=> "true",
						"type" 		=> "checkbox" );

	$options[] = array( "name" 		=> __( 'Intro - Custom Background', 'woothemes' ),
						"desc" 		=> __( 'Upload a background image for your hero section, or specify an image URL directly.', 'woothemes' ),
						"id" 		=> $shortname."_hero_bg",
						"std" 		=> "",
						"type" 		=> "upload" );

	$options[] = array( "name" 		=> __( 'Intro - Title', 'woothemes' ),
						"desc" 		=> __( 'Enter the intro title.', 'woothemes' ),
						"id" 		=> $shortname."_hero_title",
						"std" 		=> "",
						"type" 		=> "text");

	$options[] = array( "name" 		=> __( 'Intro - Title Font Style', 'woothemes' ),
						"desc" 		=> __( 'Select typography for the hero title.', 'woothemes' ),
						"id" 		=> $shortname."_hero_title_font",
						"std" 		=> array('size' => '3','unit' => 'em', 'face' => 'Lato', 'style' => 'thin', 'color' => '#fff'),
						"type" 		=> "typography");

	$options[] = array( "name" 		=> __( 'Intro - Message', 'woothemes' ),
						"desc" 		=> __( 'Enter the Intro message.', 'woothemes' ),
						"id" 		=> $shortname."_hero_message",
						"std" 		=> "",
						"type" 		=> "textarea");

	$options[] = array( "name" 		=> __( 'Intro - Opening Hours', 'woothemes' ),
						"desc" 		=> __( 'Enter your opening hours.', 'woothemes' ),
						"id" 		=> $shortname."_hero_hours",
						"std" 		=> "",
						"type" 		=> "text");

	$options[] = array( "name" 		=> __( 'Intro - Button', 'woothemes' ),
						"desc" 		=> __( 'Enter the Intro button text.', 'woothemes' ),
						"id" 		=> $shortname."_hero_button",
						"std" 		=> "",
						"type" 		=> "text");

	$options[] = array( "name" 		=> __( 'Intro - Button Link', 'woothemes' ),
						"desc" 		=> __( 'Enter the Intro button url.', 'woothemes' ),
						"id" 		=> $shortname."_hero_button_link",
						"std" 		=> "",
						"type" 		=> "text");

	$options[] = array( "name" 		=> __( 'Intro - Menu Button', 'woothemes' ),
						"desc" 		=> sprintf( __( 'Display a link to your menu. Requires the %sRestaurant%s plugin', 'woothemes' ), '<a href="https://wordpress.org/plugins/restaurant/">', '</a>' ),
						"id" 		=> $shortname."_hero_menu_link",
						"std" 		=> "false",
						"type" 		=> "checkbox" );

	$options[] = array( "name" 		=> __( 'Menu - Currency Symbol', 'woothemes' ),
						"desc" 		=> sprintf( __( 'The currency symbol to display on your menu. Requires the %sRestaurant%s plugin', 'woothemes' ), '<a href="https://wordpress.org/plugins/restaurant/">', '</a>' ),
						"id" 		=> $shortname."_menu_currency",
						"std" 		=> "$",
						"type" 		=> "text" );

	return $options;
}

function woo_custom_fonts_output() {
	global $woo_options;
	$output = '';

	if ( isset( $woo_options['woo_hero_bg'] ) && '' != $woo_options['woo_hero_bg'] ) {
		$output .= '.hero-wrapper { background-image: url(' . esc_url( $woo_options['woo_hero_bg'] ) . '); }' . "\n";
	}

	if ( isset( $woo_options['woo_hero_title_font'] ) ) {
		$output .= '.hero .section-title { ' . woo_generate_font_css( $woo_options['woo_hero_title_font'], 1.2 ) . ' }' . "\n";
	}

	if ( isset( $output ) && '' != $output ) {
		$output = "\n<!-- Woo Custom Styling -->\n<style type=\"text/css\">\n" . $output . "</style>\n<!-- /Woo Custom Styling -->\n\n";
		echo $output;
	}
}

/**
 * Display Hero.
 *
 * Displays products which have been set as “featured” using the WooCommerce featured_products shortcode.
 *
 * @since  	1.0.0
 * @return 	void
 * @uses  	do_shortcode()
 * @link 	http://www.woothemes.com/woocommerce/
 * @author 	WooThemes
 */
function woo_display_hero() {
 	$settings = array(
					'hero_title'		=> '',
					'hero_message' 		=> '',
					'hero_hours'		=> '',
					'hero_button' 		=> '',
					'hero_button_link' 	=> '',
					'hero_menu_link'	=> 'false',
				);

	$settings = woo_get_dynamic_values( $settings );

	if ( ( $settings['hero_title'] != '' || $settings['hero_message'] != '' || $settings['hero_button'] != '' || $settings['hero_button_link'] != '' ) && ( is_page_template( 'template-homepage.php' ) ) ) {
	?>
		<section class="hero home-section">
			<div class="col-full">
				<div class="hero-container">
					<?php if ( isset( $settings['hero_title'] ) && '' != $settings['hero_title'] ): ?>
						<h1 class="section-title"><span><?php echo wp_kses_post( stripslashes( $settings['hero_title'] ) ); ?></span></h1>
					<?php endif; ?>

					<?php if ( isset( $settings['hero_message'] ) && '' != $settings['hero_message'] ): ?>
						<?php echo wpautop( wp_kses_post( stripslashes( $settings['hero_message'] ) ) ); ?>
					<?php endif; ?>

					<div class="cta">
						<?php if ( isset( $settings['hero_button'] ) && '' != $settings['hero_button'] ): ?>
							<a class="button alt" href="<?php echo esc_url( $settings['hero_button_link'] ); ?>"><?php echo esc_attr( $settings['hero_button'] ); ?></a>
						<?php endif; ?>

						<?php
							if ( class_exists( 'RP_Restaurant' ) && 'true' == $settings['hero_menu_link'] ) {
								$slug 		= apply_filters( 'rp_restaurant_menu_base', 'menu' );
								$menu_url	= site_url( $slug );

								echo '<a href="' . $menu_url . '" class="button">' . __( 'View our menu', 'woothemes' ) . '</a>';
							}
						?>

					</div>

					<?php if ( isset( $settings['hero_hours'] ) && '' != $settings['hero_hours'] ): ?>
						<div class="opening-hours">
							<?php echo wpautop( wp_kses_post( stripslashes( $settings['hero_hours'] ) ) ); ?>
						</div>
					<?php endif; ?>
				</div>
			</div>
		</section>
	<?php
	}
}

/**
 * Display Testimonials.
 *
 * Displays the most recent testimonial.
 *
 * @since  	1.0.0
 * @return 	void
 * @uses  	do_action()
 * @link 	http://www.woothemes.com/woocommerce/
 * @author 	WooThemes
 */
function woo_display_testimonials() {
	if ( class_exists( 'Woothemes_Testimonials' ) ) { ?>

		<section class="home-section testimonials">

			<h2 class="section-title"><?php _e( 'Happy Customers', 'woothemes' ); ?></h2>

			<?php

			$limit 		= apply_filters( 'woo_template_testimonials_limit', $testimonials_limit = 2 );
			$columns 	= apply_filters( 'woo_template_testimonials_columns', $testimonials_columns = 2 );

			do_action( 'woothemes_testimonials', apply_filters( 'woo_template_testimonials_args', array(
				'limit' 	=> $limit,
				'per_row' 	=> $columns
				) )
			);

			?>

		</section>

	<?php }
}

/**
 * Display Contact Details
 * @uses do_shortcode()
 */
function woo_display_contact() {
	if ( class_exists( 'Contact_Details_by_WooThemes' ) ) {
		echo '<section class="home-section contact col-full">';

		echo '<h2 class="section-title">' . __( 'Come dine with us', 'woothemes' ) . '</h2>';

		do_action( 'contact_details', array( 'display' => 'all' ) );

		echo '</section>';
	}
}

/**
 * Display WooSlider slides in the 'homepage' slide group.
 * @uses do_shortcode()
 */
function woo_display_wooslider() {
	if ( class_exists( 'WooSlider' ) ) {

		$slider_settings = apply_filters( 'woo_slider_template_settings', array(
			'slider_type'		=> 'slides',
			'smoothheight'		=> true,
			'direction_nav' 	=> true,
			'keyboard_nav' 		=> true,
			'mousewheel_nav' 	=> false,
			'playpause' 		=> 'play',
			'animation_loop' 	=> true,
			'pause_on_action' 	=> true,
			'pause_on_hover' 	=> true,
			'touch' 			=> true
			)
		);

		$slides_args = apply_filters( 'woo_slider_template_args', $args = array(
			'slide_page' 	=> 'homepage',
			'imageslide' 	=> 'true',
			'link_slide' 	=> 'true',
			'overlay' 		=> 'full',
			'layout' 		=> 'text-bottom',
			'display_title' => 'true'
			)
		);

		// Fire wooslider.
		echo '<section class="home-section wooslider-wrapper">';
			wooslider( $slider_settings, $slides_args );
		echo '</section>';

	}
}

/**
 * Hero wrapper
 * Wraps the hero for the full screen background affect
 * @since 1.0.0
 */
function woo_hero_wrapper() {
	echo '<section class="hero-wrapper">';
}

/**
 * Hero wrapper close
 * Closes the hero wrapper
 * @since 1.0.0
 */
function woo_hero_wrapper_close() {
	echo '</section>';
}

/**
 * Header Contact
 * Displays contact details in the header.
 * @uses  Contact+Details_by_WooThemes plugin class
 * @link  http://wordpress.org/plugins/contact-details-by-woothemes/
 * @since 1.0.0
 */
function woo_header_contact() {
	if ( class_exists( 'Contact_Details_by_WooThemes' ) ) {
		$contact = Contact_Details_by_WooThemes();

		$phone_number 	= esc_attr( $contact->settings->get_value( 'phone_number', '', 'contact-fields' ) );
		$twitter 		= esc_attr( $contact->settings->get_value( 'twitter', '', 'contact-fields' ) );
		$facebook 		= esc_attr( $contact->settings->get_value( 'facebook', '', 'contact-fields' ) );

		?>
		<section class="header-contact col-full">
			<ul class="contact-details">
		<?php

				if ( $phone_number ) {
					echo '<li class="phone"><a href="tel:' . $phone_number . '">' . $phone_number . '</a></li>';
				}

				if ( $twitter || $facebook ) {
					echo '<li class="connect">' . __( 'Connect with us:', 'woothemes' ) . '</li>';
				}

				if ( $twitter ) {
					echo '<li class="twitter"><a href="' . $twitter . '">' . __( 'Twitter', 'woothemes' ) . '</a></li>';
				}

				if ( $facebook ) {
					echo '<li class="facebook"><a href="' . $facebook . '">' . __( 'Facebook', 'woothemes' ) . '</a></li>';
				}

		?>
			</ul>
		</section>
		<?php
	}
}

/**
 * Add an odd or even class to posts
 * @since 1.0.0
 */
function odd_even_post_class ( $classes ) {
   global $current_class;
   $classes[] = $current_class;

   $current_class = ( $current_class == 'odd' ) ? 'even' : 'odd';

   return $classes;
}
add_filter ( 'post_class' , 'odd_even_post_class' );
global $current_class;
$current_class = 'odd';

/**
 * Plugin integrations
 * filters the WooFramework to display additional plugins for users to install.
 * @since 1.0.0
 */
function bon_appetit_plugin_integrations( $integrations ) {

	$integrations['restaurant/restaurant.php'] 	= array(
													'name' 			=> __( 'Restaurant', 'woothemes' ),
													'description' 	=> __( 'Create and manage a basic food and beverage menu.', 'woothemes' ),
													'global'		=> false,
													);

	$integrations['restaurant-reservations/restaurant-reservations.php'] 	= array(
													'name' 			=> __( 'Restaurant Reservations', 'woothemes' ),
													'description' 	=> __( 'Accept restaurant reservations and bookings online.', 'woothemes' ),
													'global'		=> false,
													);
	return $integrations;
}

/**
 * Bon Appetit plugin support declaration
 * @since 1.0.0
 */
function bon_appetit_plugin_support() {
	add_theme_support( 'restaurant' );
	add_theme_support( 'restaurant-reservations' );
	add_theme_support( 'contact-details-by-woothemes' );
}

/**
 * Display Recent Posts.
 *
 * Displays recent blog posts.
 *
 * @since  	1.0.0
 * @return 	void
 * @uses  	WP_Query()
 * @link 	http://www.woothemes.com/woocommerce/
 * @author 	WooThemes
 */
function woo_display_recent_posts() {

/**
 * The Variables
 *
 * Setup default variables, overriding them if the "Theme Options" have been saved.
 */

 	$settings = array(
					'thumb_w' => 700,
					'thumb_h' => 700,
					'thumb_align' => 'alignleft'
					);

	$settings = woo_get_dynamic_values( $settings );

?>

	<section class="home-section">

		<div class="col-full">

			<section class="recent-posts">
				<?php
					$args = array(
								'posts_per_page' => 1,
							);

					$recent_posts = new WP_Query( $args );
				?>

				<?php if ( $recent_posts->have_posts() ) : ?>
					<?php while ( $recent_posts->have_posts() ) : $recent_posts->the_post(); ?>
						<article <?php post_class(); ?>>

							<?php
							if ( has_post_thumbnail() ) {
								the_post_thumbnail();
							}
							?>

							<div class="post-content">

								<header class="post-header">
									<p class="meta">
										<span class="post-date"><?php echo human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) . __( ' ago', 'woothemes' ); ?></span>
									</p>
									<h1><a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h1>
								</header>

								<p><?php echo get_the_excerpt(); ?></p>

								<footer class="post-more">
									<p>
										<span class="read-more"><a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php _e( 'Read More', 'woothemes' ); ?></a></span>
									</p>
									<p class="meta">
										<span class="categories"><?php the_category( ', ' ); ?></span>
									</p>
								</footer>

							</div>

						</article><!-- /.post -->
					<?php endwhile; ?>
				<?php endif; ?>

			</section>

		</div>

	</section>

<?php
}